Bifrost: src Directory Reference

Bifrost

src Directory Reference

## Files
file | ColoredCDBG.hpp [code]
| Interface for the Colored and Compacted de Bruijn graph API.
file | ColorSet.hpp [code]
| Interface for UnitigColors, the unitig container of k-mer color sets used in ColoredCDBG.
file | CompactedDBG.hpp [code]
| Interface for the Compacted de Bruijn graph API.
file | DataAccessor.hpp [code]
| Interface for the class DataAccessor.
file | Kmer.hpp [code]
| Interface for the class Kmer:
file | NeighborIterator.hpp [code]
| The neighborIterator, BackwardCDBG and ForwardCDBG type interfaces.
file | Unitig.hpp [code]
| The Unitig interface.
file | UnitigIterator.hpp [code]
| The unitigIterator type interface.
file | UnitigMap.hpp [code]
| UnitigMap type interface.